

/** @file MF2lib.h
 *  @brief MF2Lib module header. The library performs change detection robust to suddent illumination changes. 
 *  Please see http://vision.deis.unibo.it/research/78-cvlab/94-mf-cd for more details.
 *
 *  The algorithm was proposed in the following scientific publication:
 *  L. Di Stefano, F. Tombari, S. Mattoccia, E. De Lisi
 *  "Robust and accurate change detection under sudden illumination variations
 *  ACCV07 Workshop on Multi-dimensional and Multi-view Image Processing (ACCV WS 2007)
 *
 *	Dependencies: the library requires OpenCV (version 2.4.2 or higher), in particular needs to 
 *  be linked to the following OpenCV modules:
 *  core, highgui, imgproc
 *
 *  @author Federico Tombari
 */

#ifndef MF2LIB_H_
#define MF2LIB_H_

#include "opencv2/opencv.hpp"
#include "opencv2/legacy/compat.hpp"
#include "opencv2/legacy/legacy.hpp"

void mf2BackgroundModeling(IplImage* background, int SBL);
void mf2ChangeDetection(IplImage* currentFrame, IplImage* background, IplImage* dest, int SBL, float MF2Th, int diffTh );

#endif